@@ -1499,28 +1499,6 @@ litest_touch_move_extended(struct litest_device *d,
 	litest_slot_move(d, slot, x, y, axes, true);
 }
 
-void
-litest_touch_move_to_extended(struct litest_device *d,
-			      unsigned int slot,
-			      double x_from, double y_from,
-			      double x_to, double y_to,
-			      struct axis_replacement *axes,
-			      int steps, int sleep_ms)
-{
-	for (int i = 0; i < steps - 1; i++) {
-		litest_touch_move_extended(d, slot,
-					   x_from + (x_to - x_from)/steps * i,
-					   y_from + (y_to - y_from)/steps * i,
-					   axes);
-		if (sleep_ms) {
-			libinput_dispatch(d->libinput);
-			msleep(sleep_ms);
-			libinput_dispatch(d->libinput);
-		}
-	}
-	litest_touch_move_extended(d, slot, x_to, y_to, axes);
-}
-
 void
 litest_touch_move_to(struct litest_device *d,
 		     unsigned int slot,
@@ -1528,11 +1506,17 @@ litest_touch_move_to(struct litest_device *d,
 		     double x_to, double y_to,
 		     int steps, int sleep_ms)
 {
-	litest_touch_move_to_extended(d, slot,
-				      x_from, y_from,
-				      x_to, y_to,
-				      NULL,
-				      steps, sleep_ms);
+	for (int i = 0; i < steps - 1; i++) {
+		litest_touch_move(d, slot,
+				  x_from + (x_to - x_from)/steps * i,
+				  y_from + (y_to - y_from)/steps * i);
+		if (sleep_ms) {
+			libinput_dispatch(d->libinput);
+			msleep(sleep_ms);
+			libinput_dispatch(d->libinput);
+		}
+	}
+	litest_touch_move(d, slot, x_to, y_to);
 }
 
 static int
@@ -2248,8 +2232,12 @@ litest_create_uinput(const char *name,
 
 	abs = abs_info;
 	while (abs && abs->value != -1) {
-		rc = libevdev_enable_event_code(dev, EV_ABS,
-						abs->value, abs);
+		struct input_absinfo a = *abs;
+
+		/* abs_info->value is used for the code and may be outside
+		   of [min, max] */
+		a.value = abs->minimum;
+		rc = libevdev_enable_event_code(dev, EV_ABS, abs->value, &a);
 		litest_assert_int_eq(rc, 0);
 		abs++;
 	}
